#   Copyright (C) 2023-2024 Credit Mutuel Arkea
#
#   Licensed under the Apache License, Version 2.0 (the "License");
#   you may not use this file except in compliance with the License.
#   You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
#   Unless required by applicable law or agreed to in writing, software
#   distributed under the License is distributed on an "AS IS" BASIS,
#   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#   See the License for the specific language governing permissions and
#   limitations under the License.
#
"""Model for creating BaseVectorStoreSetting."""
from typing import Optional

from pydantic import BaseModel, Field

from gen_ai_orchestrator.models.vector_stores.vectore_store_provider import VectorStoreProvider


class BaseVectorStoreSetting(BaseModel):
    """A base class for Vector Store Setting."""

    provider: VectorStoreProvider = Field(description='The Vector Store Provider.')
    vector_size: int = Field(
        description='The size of the embedding vector.', examples=[1536], default=1536,
        ge=1
    )

